// Persistence of Vision Ray Tracer Scene Description File
// File: colorbox.pov
// Vers: 3.5
// Desc: A cube made of tiny colored particles, which may be useful, or just fun.
// Date: 07-06-05
// Auth: Tyler Breisacher



/*
ColorDepth is the number of different values between 0 and 1 that the R, G, and B can have.

It should be a positive integer, but remember that the cube contains ColorDepth^3 different 
colors, so if you set it too high, it will take forever to render. For example, at 
ColorDepth=100, there will be a million tiny colored spheres/cubes!

RedRange, GreenRange, and BlueRange define what subset of the cube will be displayed.

For example, if RedRange is <0, 0.5> then you'll only see the left (less red) half of the 
cube. If GreenRange is <0.5, 1> then you'll only see the top (more green) half.If all ranges 
are set to <0,1>, the entire cube will be rendered.

Don't try to use rgb values less than 0 or greater than 1 - that makes no sense.
And of course, the first number should be lower than the second.
*/
#declare ColorDepth = 20 ;
#declare RedRange = <0,1> ;
#declare GreenRange = <0,1> ;
#declare BlueRange = <0,1> ;
#declare ParticleFinish = finish {ambient 0.25 phong 1} 

//--------------------//

#declare Increment = 1/ColorDepth ;
/*Sphere Version
Each color is represented by a tiny sphere*/
#declare BlueCount = BlueRange.u ;
#while (BlueCount < BlueRange.v)
  #declare GreenCount = GreenRange.u ;
  #while (GreenCount < GreenRange.v)
    #declare RedCount = RedRange.u ;
    #while (RedCount < RedRange.v)
      sphere {<RedCount,GreenCount,BlueCount>, Increment/2
        pigment {rgb <RedCount,GreenCount,BlueCount>}
        finish {ParticleFinish}
      } 
    #declare RedCount = RedCount+Increment ;
    #end
  #declare GreenCount = GreenCount+Increment ;
  #end
#declare BlueCount = BlueCount+Increment ;
#end

/* Box Version 
Each color is its own box, so if ColorDepth is big enough, it looks like a smooth gradient*/
/*
#declare BlueCount = BlueRange.u ;
#while (BlueCount < BlueRange.v)
  #declare GreenCount = GreenRange.u ;
  #while (GreenCount < GreenRange.v)
    #declare RedCount = RedRange.u ;
    #while (RedCount < RedRange.v)
      box {
        <RedCount,GreenCount,BlueCount>
        <RedCount,GreenCount,BlueCount>+Increment
        pigment {rgb <RedCount,GreenCount,BlueCount>}
        finish {ParticleFinish}
      } 
    #declare RedCount = RedCount+Increment ;
    #end
  #declare GreenCount = GreenCount+Increment ;
  #end
#declare BlueCount = BlueCount+Increment ;
#end
*/
 
camera{
  location <-2,2,-1>
  look_at 0.5
  angle 50
}
#declare WallTexture = 
pigment {checker 
  rgb 1
  rgb 0.75
  scale 0.25
} ;

plane {z, 1+Increment/2 
  texture {WallTexture}
}
plane {x, 1+Increment/2 
  texture {WallTexture}
}
plane {y, -Increment/2
  texture {WallTexture}
}

light_source{ <0.5,10,-10> 1 }
light_source{ <-10,10,0.5> 1 }
                              

